@@ -129,7 +129,7 @@ yaml = YAML()
 yaml.indent(mapping=2, sequence=4, offset=2)
 indent4 = partial(indent, prefix="    ")
 
-SPYVER = get_version(SPYREPO).strip().split("+")[0]
+SPYVER = get_version(SPYREPO, normalize=False).lstrip('v').split("+")[0]
 
 specs = {
     "spyder": "=" + SPYVER,
@@ -233,6 +233,8 @@ def _definitions():
         ],
         "installer_filename": OUTPUT_FILE.name,
         "initialize_by_default": False,
+        "initialize_conda": False,
+        "register_python": False,
         "license_file": str(RESOURCES / "bundle_license.rtf"),
         "extra_envs": {
             f"spyder-{SPYVER}": {
@@ -292,7 +294,6 @@ def _definitions():
                 "welcome_image": str(DIST / "spyder_164x314.png"),
                 "header_image": str(DIST / "spyder_150x57.png"),
                 "icon_image": str(SPYREPO / "img_src" / "spyder.ico"),
-                "register_python_default": False,
                 "default_prefix": os.path.join(
                     "%LOCALAPPDATA%", INSTALLER_DEFAULT_PATH_STEM
                 ),
