@@ -560,17 +560,32 @@ class ConfigurationManager(object):
         """Remove `option` from `section`."""
         config = self.get_active_conf(section)
         if isinstance(option, tuple):
+            # The actual option saved in the config
             base_option = option[0]
+
+            # Keys of the nested dicts where the option to remove is contained
             intermediate_options = option[1:-1]
+
+            # Key of the option to remove
             last_option = option[-1]
 
+            # Get config value (which is a dictionary)
             base_conf = self.get(section, base_option)
+
+            # Get reference to the actual dictionary containing the option
+            # that needs to be removed
             conf_ptr = base_conf
             for opt in intermediate_options:
                 conf_ptr = conf_ptr[opt]
-            conf_ptr.pop(last_option)
-            self.set(section, base_option)
-            self.notify_observers(section, base_option)
+
+            # Remove option and set updated config values for the actual option
+            # while checking that the option to be removed is actually a value
+            # available in the config.
+            # See spyder-ide/spyder#21161
+            if last_option in conf_ptr:
+                conf_ptr.pop(last_option)
+                self.set(section, base_option,  base_conf)
+                self.notify_observers(section, base_option)
         else:
             config.remove_option(section, option)
 
@@ -689,7 +704,7 @@ except Exception:
     # fallback fail.
     # See issue spyder-ide/spyder#17889
     if app is None:
-        app = QApplication(['Spyder'])
+        app = QApplication(['Spyder', '--no-sandbox'])
         app.setApplicationName('Spyder')
 
     reset_reply = QMessageBox.critical(
