@@ -16,11 +16,12 @@ import functools
 import inspect
 import logging
 import os
-from pkg_resources import parse_version, iter_entry_points
 from typing import List, Union
 import weakref
 
 # Third-party imports
+from packaging.version import parse
+from pkg_resources import iter_entry_points
 from qtpy.QtCore import QMutex, QMutexLocker, QTimer, Slot, Signal
 
 # Local imports
@@ -739,8 +740,8 @@ class CompletionPlugin(SpyderPluginV2):
 
         # Check if there were any version changes between configurations
         provider_config = provider_configurations[provider_name]
-        provider_conf_version = parse_version(Provider.CONF_VERSION)
-        current_conf_version = parse_version(provider_config['version'])
+        provider_conf_version = parse(Provider.CONF_VERSION)
+        current_conf_version = parse(provider_config['version'])
 
         current_conf_values = provider_config['values']
         current_defaults = provider_config['defaults']
@@ -947,7 +948,15 @@ class CompletionPlugin(SpyderPluginV2):
         """Start a given provider."""
         provider_info = self.providers[provider_name]
         if provider_info['status'] == self.STOPPED:
-            provider_info['instance'].start()
+            provider_instance = provider_info['instance']
+            provider_instance.start()
+            for language in self.language_status:
+                language_providers = self.language_status[language]
+                language_providers[provider_name] = (
+                    provider_instance.start_completion_services_for_language(
+                        language
+                    )
+                )
 
     def shutdown_provider_instance(self, provider_name: str):
         """Shutdown a given provider."""
@@ -955,6 +964,10 @@ class CompletionPlugin(SpyderPluginV2):
         if provider_info['status'] == self.RUNNING:
             provider_info['instance'].shutdown()
             provider_info['status'] = self.STOPPED
+            for language in self.language_status:
+                language_providers = self.language_status[language]
+                if provider_name in language_providers:
+                    language_providers[provider_name] = False
 
     # ---------- Methods to create/access graphical elements -----------
     def create_action(self, *args, **kwargs):
