@@ -19,7 +19,7 @@ from qtpy.QtCore import Signal, Slot
 from spyder.api.plugins import Plugins, SpyderDockablePlugin
 from spyder.api.plugin_registration.decorators import (
     on_plugin_available, on_plugin_teardown)
-from spyder.api.translations import get_translation
+from spyder.api.translations import _
 from spyder.plugins.ipythonconsole.confpage import IPythonConsoleConfigPage
 from spyder.plugins.ipythonconsole.widgets.main_widget import (
     IPythonConsoleWidget, IPythonConsoleWidgetOptionsMenus)
@@ -27,9 +27,6 @@ from spyder.plugins.mainmenu.api import (
     ApplicationMenus, ConsolesMenuSections, HelpMenuSections)
 from spyder.utils.programs import get_temp_dir
 
-# Localization
-_ = get_translation('spyder')
-
 
 class IPythonConsole(SpyderDockablePlugin):
     """
