@@ -43,7 +43,7 @@ from spyder.py3compat import to_text_string
 from spyder.plugins.help.tests.test_plugin import check_text
 from spyder.plugins.ipythonconsole.tests.conftest import (
     get_conda_test_env, get_console_background_color, get_console_font_color,
-    NEW_DIR, SHELL_TIMEOUT, TEMP_DIRECTORY)
+    NEW_DIR, SHELL_TIMEOUT, TEMP_DIRECTORY, PY312_OR_GREATER)
 from spyder.plugins.ipythonconsole.widgets import ClientWidget
 from spyder.utils.programs import get_temp_dir
 from spyder.utils.conda import get_list_conda_envs
@@ -1943,8 +1943,9 @@ def test_pdb_comprehension_namespace(ipyconsole, qtbot, tmpdir):
     with qtbot.waitSignal(shell.executed):
         shell.execute(f"debugfile(filename=r'{str(file)}')")
 
-    # steps 4 times
-    for i in range(4):
+    # steps into the comprehension
+    comprehension_steps = 2 if PY312_OR_GREATER else 4
+    for i in range(comprehension_steps):
         with qtbot.waitSignal(shell.executed):
             shell.pdb_execute("s")
     assert "Error" not in control.toPlainText()
