@@ -24,9 +24,9 @@ from traitlets import observe
 # Local imports
 from spyder.config.base import (
     _, is_pynsist, running_in_mac_app, running_under_pytest)
-from spyder.config.gui import get_color_scheme
+from spyder.config.gui import get_color_scheme, is_dark_interface
 from spyder.py3compat import to_text_string
-from spyder.utils.palette import SpyderPalette
+from spyder.utils.palette import QStylePalette, SpyderPalette
 from spyder.utils.clipboard_helper import CLIPBOARD_HELPER
 from spyder.utils import syntaxhighlighters as sh
 from spyder.plugins.ipythonconsole.utils.style import (
@@ -500,7 +500,6 @@ class ShellWidget(NamepaceBrowserWidget, HelpWidget, DebuggingWidget,
         if sympy_o:
             lines = """
 These commands were executed:
->>> from __future__ import division
 >>> from sympy import *
 >>> x, y, z, t = symbols('x y z t')
 >>> k, m, n = symbols('k m n', integer=True)
@@ -617,7 +616,6 @@ the sympy module (e.g. plot)
                     self.silent_execute("from pylab import *")
                 if kernel_env.get('SPY_SYMPY_O') == 'True':
                     sympy_init = """
-                        from __future__ import division
                         from sympy import *
                         x, y, z, t = symbols('x y z t')
                         k, m, n = symbols('k m n', integer=True)
@@ -821,7 +819,7 @@ the sympy module (e.g. plot)
             Type of message to be showm. Possible values are
             'warning' and 'error'.
         """
-        # The message is displayed in a table with a single cell.
+        # The message is displayed in a table with a header and a single cell.
         table_properties = (
             "border='0.5'" +
             "width='90%'" +
@@ -833,14 +831,27 @@ the sympy module (e.g. plot)
             header = _("Error")
             bgcolor = SpyderPalette.COLOR_ERROR_2
         else:
-            header = _("Warning")
+            header = _("Important")
             bgcolor = SpyderPalette.COLOR_WARN_1
 
+        # This makes the header text have good contrast against its background
+        # for the light theme.
+        if is_dark_interface():
+            font_color = QStylePalette.COLOR_TEXT_1
+        else:
+            font_color = 'white'
+
         self._append_html(
-            f"<div align='center'><table {table_properties}>" +
-            f"<tr><th bgcolor='{bgcolor}'>{header}</th></tr>" +
-            "<tr><td>" + html + "</td></tr>" +
-            "</table></div>",
+            f"<div align='center'>"
+            f"<table {table_properties}>"
+            # Header
+            f"<tr><th bgcolor='{bgcolor}'><font color='{font_color}'>"
+            f"{header}"
+            f"</th></tr>"
+            # Cell with html message
+            f"<tr><td>{html}</td></tr>"
+            f"</table>"
+            f"</div>",
             before_prompt=before_prompt
         )
 
