@@ -14,7 +14,7 @@ NumPy Array Editor Dialog based on Qt
 # pylint: disable=R0201
 
 # Standard library imports
-from __future__ import print_function
+import io
 
 # Third party imports
 from qtpy.compat import from_qvariant, to_qvariant
@@ -35,9 +35,8 @@ from spyder.config.base import _
 from spyder.config.fonts import DEFAULT_SMALL_DELTA
 from spyder.config.gui import get_font
 from spyder.config.manager import CONF
-from spyder.py3compat import (io, is_binary_string, is_string,
-                              is_text_string, PY3, to_binary_string,
-                              to_text_string)
+from spyder.py3compat import (is_binary_string, is_string, is_text_string,
+                              to_binary_string, to_text_string)
 from spyder.utils.icon_manager import ima
 from spyder.utils.qthelpers import add_actions, create_action, keybinding
 from spyder.plugins.variableexplorer.widgets.basedialog import BaseDialog
@@ -558,10 +557,7 @@ class ArrayView(QTableView):
             row_max = self.model().total_rows-1
 
         _data = self.model().get_data()
-        if PY3:
-            output = io.BytesIO()
-        else:
-            output = io.StringIO()
+        output = io.BytesIO()
         try:
             np.savetxt(output, _data[row_min:row_max+1, col_min:col_max+1],
                        delimiter='\t', fmt=self.model().get_format())
@@ -663,9 +659,16 @@ class ArrayEditor(BaseDialog):
         """
         self.data = data
         readonly = readonly or not self.data.flags.writeable
-        is_record_array = data.dtype.names is not None
         is_masked_array = isinstance(data, np.ma.MaskedArray)
 
+        # This is necessary in case users subclass ndarray and set the dtype
+        # to an object that is not an actual dtype.
+        # Fixes spyder-ide/spyder#20462
+        if hasattr(data.dtype, 'names'):
+            is_record_array = data.dtype.names is not None
+        else:
+            is_record_array = False
+
         if data.ndim > 3:
             self.error(_("Arrays with more than 3 dimensions are not "
                          "supported"))
@@ -679,7 +682,14 @@ class ArrayEditor(BaseDialog):
                          "number"))
             return False
         if not is_record_array:
-            dtn = data.dtype.name
+            # This is necessary in case users subclass ndarray and set the
+            # dtype to an object that is not an actual dtype.
+            # Fixes spyder-ide/spyder#20462
+            if hasattr(data.dtype, 'name'):
+                dtn = data.dtype.name
+            else:
+                dtn = 'Unknown'
+
             if dtn == 'object':
                 # If the array doesn't have shape, we can't display it
                 if data.shape == ():
@@ -691,7 +701,7 @@ class ArrayEditor(BaseDialog):
                 self.readonly = readonly = True
             elif (dtn not in SUPPORTED_FORMATS and not dtn.startswith('str')
                     and not dtn.startswith('unicode')):
-                arr = _("%s arrays") % data.dtype.name
+                arr = _("%s arrays") % dtn
                 self.error(_("%s are currently not supported") % arr)
                 return False
 
