@@ -33,9 +33,8 @@ from spyder.widgets.collectionseditor import (
     CollectionsModel, CollectionsEditor, LARGE_NROWS, ROWS_TO_LOAD, natsort)
 from spyder.plugins.variableexplorer.widgets.namespacebrowser import (
     NamespacesBrowserFinder)
-from spyder.plugins.variableexplorer.widgets.tests.test_dataframeeditor import \
-    generate_pandas_indexes
-from spyder.py3compat import PY2, to_text_string
+from spyder.plugins.variableexplorer.widgets.tests.test_dataframeeditor import (
+    generate_pandas_indexes)
 from spyder_kernels.utils.nsview import get_size
 
 
@@ -383,7 +382,6 @@ def test_sort_float_collectionsmodel():
                                       '0.1', '1.0', '10.0', '1e+16']]
 
 
-@pytest.mark.skipif(os.name == 'nt' and PY2, reason='Fails on Win and py2')
 def test_sort_collectionsmodel():
     var_list1 = [0, 1, 2]
     var_list2 = [3, 4, 5, 6]
