@@ -115,7 +115,7 @@ class WorkerUpdates(QObject):
         elif is_anaconda():
             channel, channel_url = get_spyder_conda_channel()
 
-            if channel_url is None:
+            if channel is None or channel_url is None:
                 return
             elif channel == "pypi":
                 self.url = pypi_url
@@ -154,7 +154,7 @@ class WorkerUpdates(QObject):
             error_msg = CONNECT_ERROR_MSG
             logger.debug(err, stack_info=True)
         except HTTPError as err:
-            error_msg = HTTP_ERROR_MSG.format(page.status_code)
+            error_msg = HTTP_ERROR_MSG.format(status_code=page.status_code)
             logger.debug(err, stack_info=True)
         except Exception as err:
             error = traceback.format_exc()
